import numpy as np

import tensorflow as tf

from tensorflow_tts.inference import TFAutoModel
from tensorflow_tts.inference import AutoProcessor

class TTS(object):

    """
    🤗 Apply Text-To-Speech Inference and get Audio content
    """ 
    def __new__(cls, lang="fr", text="Bonjour le monde"):

        if lang not in ["fr","en"]:
            print("This language isn't supported yet!")

        if lang == "fr":
            return cls.frTTS(text)
        elif lang == "en":
            return cls.frTTS(text)
        else:            
            return None

    """
    French TTS Model
    """
    def frTTS(text):
        
        processor = AutoProcessor.from_pretrained("tensorspeech/tts-tacotron2-synpaflex-fr")
        tacotron2 = TFAutoModel.from_pretrained("tensorspeech/tts-tacotron2-synpaflex-fr")
        mb_melgan = TFAutoModel.from_pretrained("tensorspeech/tts-mb_melgan-synpaflex-fr")

        input_ids = processor.text_to_sequence(text)

        # tacotron2 inference (text-to-mel)
        decoder_output, mel_outputs, stop_token_prediction, alignment_history = tacotron2.inference(
            input_ids=tf.expand_dims(tf.convert_to_tensor(input_ids, dtype=tf.int32), 0),
            input_lengths=tf.convert_to_tensor([len(input_ids)], tf.int32),
            speaker_ids=tf.convert_to_tensor([0], dtype=tf.int32),
        )

        # melgan inference (mel-to-wav)
        audio = mb_melgan.inference(mel_outputs)[0, :, 0]

        return audio


#!/usr/bin/env python3
import os
import setuptools
from distutils.core import setup

with open("README.md") as f:
    long_description = f.read()

with open(os.path.join("EasyTTS", "version.txt")) as f:
    version = f.read().strip()

setup(
    name = "EasyTTS",
    version = version,
    description = "Ready-to-use Multilingual Text-To-Speech (TTS) package.",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    author = "Yanis Labrak & Others",
    author_email = "yanis.labrak@univ-avignon.fr",
    packages = setuptools.find_packages(),
    package_data = {
        "EasyTTS": [
            "version.txt"
        ]
    },
    install_requires = [
        "numpy",
        "timm",
        "torch",
        "tensorflow",
        "soundfile",
        "TensorFlowTTS",
    ],
    python_requires = ">=3.7",
    url = "https://EasyTTS.github.io/",
    keywords = ["python","transformers","huggingface","wrapper","toolkit","speech","text-to-speech","text2speech","text-2-speech","T2S","easy","voice","vocal synthesis","synthesis","Speech synthesis"],
)